@@ -20,31 +20,26 @@
 #ifndef CAMERAAPPLICATION_H
 #define CAMERAAPPLICATION_H
 
-#include <QtQuick/QQuickView>
+#include <QtQml/QQmlApplicationEngine>
 #include <QGuiApplication>
-#include <libusermetricsinput/MetricManager.h>
 
 class QDate;
 
 class CameraApplication : public QGuiApplication
 {
     Q_OBJECT
+    Q_PROPERTY(bool desktopMode READ isDesktopMode CONSTANT)
 
 public:
     CameraApplication(int &argc, char **argv);
     virtual ~CameraApplication();
-
     bool setup();
+    bool isDesktopMode() const;
 
-    Q_INVOKABLE void increaseTodaysPhotoMetrics();
-    Q_INVOKABLE void increaseTodaysVideoMetrics();
+Q_SIGNALS:
 
 private:
-    QScopedPointer<QQuickView> m_view;
-
-    UserMetricsInput::MetricManagerPtr m_metricManager;
-    UserMetricsInput::MetricPtr m_photoMetric;
-    UserMetricsInput::MetricPtr m_videoMetric;
+    QScopedPointer<QQmlApplicationEngine> m_engine;
 };
 
 #endif // CAMERAAPPLICATION_H
