@@ -19,6 +19,7 @@
 
 // Qt
 #include <QGuiApplication>
+#include <QtQml/QQmlDebuggingEnabler>
 
 // local
 #include "cameraapplication.h"
@@ -26,9 +27,14 @@
 
 #include <QDebug>
 
+static QQmlDebuggingEnabler debuggingEnabler(false);
+
 int main(int argc, char** argv)
 {
-    QGuiApplication::setApplicationName("Camera App");
+    QGuiApplication::setApplicationName("com.ubuntu.camera");
+    // Necessary for Qt.labs.settings to work
+    // Ref.: https://bugs.launchpad.net/ubuntu-ui-toolkit/+bug/1354321
+    QCoreApplication::setOrganizationDomain(QGuiApplication::applicationName());
     CameraApplication application(argc, argv);
 
     if (!application.setup()) {
